import { ChangeEvent, ReactNode } from 'react';
import { IconData } from '@equinor/eds-icons';
export interface FilterProps<T> {
    values: {
        key: T;
        label: string;
        icon?: IconData;
    }[];
    onClearFilter: (key: T) => void;
    onClearAllFilters: () => void;
    search: string;
    onSearchChange: (event: ChangeEvent<HTMLInputElement>) => void;
    onSearchEnter: (value: string) => void;
    children: ReactNode | ReactNode[];
    initialOpen?: boolean;
    placeholder?: string;
    id?: string;
    showClearFiltersButton?: boolean;
}
/**
 * @param values - Array of values to display as chips ({ value: string, label: string, icon?: IconData }[])
 * @param search - The current search value
 * @param onSearchChange - Callback when search changes
 * @param onSearchEnter - Callback when users hit {Enter} in the search field
 * @param onClearFilter - Function to call when the user clicks the delete button on a chip
 * @param onClearAllFilters - Function to call when the user clicks the clear filters button
 * @param children - ReactNode or ReactNode[] to display below when the filter is open
 * @param initialOpen - Whether the filter should be open by default, defaults to false
 * @param placeholder - Placeholder text for the search input, defaults to 'Search...'
 * @param id - ID for the search field
 * @param showClearFiltersButton - Whether to show the clear filters button, defaults to true
 */
export declare function Filter<T>({ values, search, onSearchChange, onSearchEnter, onClearFilter, onClearAllFilters, children, initialOpen, placeholder, id, showClearFiltersButton, }: FilterProps<T>): import("react/jsx-runtime").JSX.Element;
